'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const sdkRedux = require('@boldpenguin/sdk-redux');
const index_esm_min = require('./index.esm.min-2804e8af.js');
const index_esm_min$1 = require('./index.esm.min-8e8a3690.js');
const store = require('./store-fe3d3434.js');

const bpSdkNextButtonContainerCss = "";

let BpSdkNextButtonContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.bpAnalyticsTrack = index.createEvent(this, "bpAnalyticsTrack", 7);
    /**
     * Controls disabled state of button
     */
    this.buttonDisabled = false;
    /**
     * Disable navigation if active question set is incomplete
     */
    this.shouldDisableIfIncomplete = false;
    this.useExternal = false;
    this.canSave = true;
    this.areResourcesReady = true;
    this.isDisabled = false;
    this.caDisabled = false;
    this.isReady = true;
    this.isLocked = false;
    this.isFirstRun = true;
    this.classes = '';
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        if (this.storeUnsubscribe) {
          this.storeUnsubscribe();
        }
        store.store.mapDispatchToProps(this, {
          saveQuestionSet: sdkRedux.saveQuestionSet,
          updateErrors: sdkRedux.updateErrors,
          removeActiveAnswerId: sdkRedux.removeActiveAnswerId,
          switchActiveQuestionSet: sdkRedux.switchActiveQuestionSet,
          pushAnswer: sdkRedux.pushAnswer,
        });
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => ({
      activeQuestionSet: sdkRedux.getCurrentActiveQuestionSet(state),
      config: sdkRedux.getPartnerEngineConfig(state),
      answersResourceState: sdkRedux.getAnswersState(state),
      applicationFormResourceState: sdkRedux.getApplicationFormState(state),
      pendingProcesses: state.application.pendingProcesses,
      questionPoolResourceState: sdkRedux.getQuestionPoolState(state),
      questionSetResourceState: sdkRedux.getQuestionSetState(state),
      questionSetState: sdkRedux.selectQuestionSetsState(state),
      queue: state.queues.answers.queue,
      enableUserApplicationGuard: !!state.config.options.enableUserApplicationGuard,
      locked: state.application.form.locked,
      isOwner: sdkRedux.doesUserOwnApplicationForm(state),
      hasPermissionToEdit: sdkRedux.userHasPermission(state, {
        permission: index_esm_min.v.ApplicationForms,
        action: index_esm_min.h.Update,
      }),
    });
  }
  resetState() {
    this.isReady = true;
    this.isFirstRun = true;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-next-button-container');
    customElements.whenDefined('bp-sdk-external-next-button-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onShouldDisableIfIncompleteChange(this.shouldDisableIfIncomplete);
    this.onAnswersResourcesStateChange(this.answersResourceState);
    this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
    this.onHasPermissionToEdit(this.hasPermissionToEdit);
    this.onEnableUserApplicationGuard(this.enableUserApplicationGuard);
    this.onIsFirstRun(this.isFirstRun);
    this.onIsOwner(this.isOwner);
    this.onIsReady(this.isReady);
    this.onLocked(this.locked);
    this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
    this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
    this.onQueueChange(this.queue);
  }
  onEnableUserApplicationGuard(enableUserApplicationGuard) {
    this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, enableUserApplicationGuard);
  }
  onHasPermissionToEdit(hasPermission) {
    this.updateIsLocked(this.locked, this.isOwner, hasPermission, this.enableUserApplicationGuard);
  }
  onIsOwner(isOwner) {
    this.updateIsLocked(this.locked, isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  onLocked(locked) {
    this.updateIsLocked(locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  updateIsLocked(locked, isOwner, hasPermission, enableUserApplicationGuard) {
    this.isLocked = locked || (enableUserApplicationGuard && (!isOwner || !hasPermission));
  }
  onIsFirstRun(isFirstRun) {
    this.updateAreResourcesReady(isFirstRun, this.isReady);
  }
  onIsReady(isReady) {
    this.updateAreResourcesReady(this.isFirstRun, isReady);
  }
  updateAreResourcesReady(isFirstRun, isReady) {
    this.areResourcesReady = isFirstRun || isReady;
  }
  onAnswersResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: state,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onApplicationFormResourceStateChange(state) {
    if (this.isFirstRun && state === index_esm_min.i.Loaded) {
      this.isFirstRun = false;
    }
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: state,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionPoolResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: state,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionSetResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: state,
    });
  }
  calculateResourcesReady(resources = {}) {
    if (!resources ||
      resources.applicationForm !== index_esm_min.i.Loaded ||
      resources.answers === index_esm_min.i.Loading ||
      resources.questionPools === index_esm_min.i.Loading ||
      resources.questionSets === index_esm_min.i.Loading) {
      return false;
    }
    return true;
  }
  onShouldDisableIfIncompleteChange(shouldDisableIfIncomplete) {
    this.updateOnDisableIfIncomplete(shouldDisableIfIncomplete, this.activeQuestionSet);
  }
  onActiveQuestionSetChange(activeQuestionSet) {
    this.updateOnDisableIfIncomplete(this.shouldDisableIfIncomplete, activeQuestionSet);
    this.disableIfCAQuestionSet(this.shouldDisableIfIncomplete, activeQuestionSet);
  }
  onQueueChange(queue) {
    this.canSave = !(queue === null || queue === void 0 ? void 0 : queue.length) && !this.doesCurrentQuestionSetHaveAPendingProcess();
  }
  onPendingProcessesChange(processes) {
    this.canSave = !this.doesCurrentQuestionSetHaveAPendingProcess(processes);
  }
  disableIfCAQuestionSet(shouldDisableIfIncomplete, activeQuestionSet) {
    let shouldDisable = false;
    if (shouldDisableIfIncomplete && activeQuestionSet) {
      shouldDisable = index_esm_min$1.gc(activeQuestionSet);
    }
    if (this.caDisabled !== shouldDisable) {
      this.caDisabled = shouldDisable;
    }
  }
  updateOnDisableIfIncomplete(shouldDisableIfIncomplete, activeQuestionSet) {
    this.isDisabled =
      shouldDisableIfIncomplete &&
        (!activeQuestionSet ||
          !activeQuestionSet.answers ||
          !activeQuestionSet.answers.length ||
          activeQuestionSet.answers.some((answer) => !answer.is_completed && answer.required));
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-next-button-container", { activeQuestionSet: this.activeQuestionSet, answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, buttonDisabled: this.buttonDisabled, config: this.config, enableUserApplicationGuard: this.enableUserApplicationGuard, hasPermissionToEdit: this.hasPermissionToEdit, isOwner: this.isOwner, locked: this.locked, pendingProcesses: this.pendingProcesses, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSetState: this.questionSetState, queue: this.queue, shouldDisableIfIncomplete: this.shouldDisableIfIncomplete }));
  }
  handleSaveQuestionSet() {
    if (!this.isLocked) {
      const invalidAnswers = this.activeQuestionSet.answers.filter((answer) => !index_esm_min$1.pc(answer));
      if (!invalidAnswers.length) {
        this.removeActiveAnswerId();
        if (!this.activeQuestionSet.parentQuestionSetId) {
          this.callSaveQuestionSet();
        }
        else {
          if (this.parentQuestionSetCanSave()) {
            this.callSaveQuestionSet(true);
          }
          else {
            this.handleStep();
          }
        }
      }
      else {
        invalidAnswers.forEach((answer) => {
          this.updateErrors({ answer, errors: index_esm_min$1.ha(answer) });
        });
        index_esm_min$1.vx();
      }
    }
    else {
      this.switchActiveQuestionSet('forward');
    }
  }
  renderInternal() {
    return (index.h("bp-sdk-next-button", { buttonDisabled: this.buttonDisabled || !this.areResourcesReady || !this.canSave || this.isDisabled || this.caDisabled, cssClasses: !this.areResourcesReady || !this.canSave ? 'loading' : 'not-loading' }));
  }
  doesCurrentQuestionSetHaveAPendingProcess(processes) {
    const currentProcesses = processes ? processes : this.pendingProcesses;
    if (!(currentProcesses === null || currentProcesses === void 0 ? void 0 : currentProcesses.length)) {
      return false;
    }
    return currentProcesses.some((process) => process.state !== index_esm_min.k.Completed && process.question_set_id === this.activeQuestionSet.id);
  }
  parentQuestionSetCanSave() {
    const parentQuestionSet = this.questionSetState.parentQuestionSets.find((pqs) => pqs.id === this.activeQuestionSet.parentQuestionSetId);
    if (parentQuestionSet) {
      return this.questionSetState.list
        .filter((qs) => qs.parentQuestionSetId === parentQuestionSet.id)
        .every((qs) => index_esm_min$1.va(qs.answers));
    }
  }
  callSaveQuestionSet(useParent = false) {
    this.saveQuestionSet({
      config: this.config,
      appFormQuestionSet: this.activeQuestionSet,
      navigationDirection: 'forward',
      parentQuestionSet: useParent
        ? this.questionSetState.parentQuestionSets.find((pqs) => pqs.id === this.activeQuestionSet.parentQuestionSetId)
        : undefined,
    });
    this.bpAnalyticsTrack.emit({
      eventName: index_esm_min.oe.QuestionSetSaved,
      eventPayload: {
        applicationFormQuestionSetId: this.activeQuestionSet.id,
        questionSetId: this.activeQuestionSet.question_set_id,
        questionSetCode: this.activeQuestionSet.question_set.code,
      },
    });
  }
  handleStep() {
    const parent = index_esm_min$1.f4(this.activeQuestionSet, this.questionSetState);
    const newValue = index_esm_min$1.l4(this.activeQuestionSet);
    if (parent.value !== newValue) {
      this.pushAnswer(index_esm_min$1.bl(parent, newValue));
    }
    this.switchActiveQuestionSet('forward');
  }
  static get watchers() { return {
    "enableUserApplicationGuard": ["onEnableUserApplicationGuard"],
    "hasPermissionToEdit": ["onHasPermissionToEdit"],
    "isOwner": ["onIsOwner"],
    "locked": ["onLocked"],
    "isFirstRun": ["onIsFirstRun"],
    "isReady": ["onIsReady"],
    "answersResourceState": ["onAnswersResourcesStateChange"],
    "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
    "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
    "questionSetResourceState": ["onQuestionSetResourcesStateChange"],
    "shouldDisableIfIncomplete": ["onShouldDisableIfIncompleteChange"],
    "activeQuestionSet": ["onActiveQuestionSetChange"],
    "queue": ["onQueueChange"],
    "pendingProcesses": ["onPendingProcessesChange"]
  }; }
};
BpSdkNextButtonContainer.style = bpSdkNextButtonContainerCss;

exports.bp_sdk_next_button_container = BpSdkNextButtonContainer;
