import { getConfigOptions, removeActiveAnswerId, updateActiveQuestionSet } from '@boldpenguin/sdk-redux';
import { Component, Element, h, Listen, Prop, State, Watch } from '@stencil/core';
import { store } from '@stencil/redux';
import { canGetStore } from '../../utils/store';
export class BpSdkQuestionSetNavigationContainer {
  constructor() {
    this.useExternal = false;
    this.questionSetList = [];
    this.isNavigationEnabled = true;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { updateActiveQuestionSet, removeActiveAnswerId });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        questionSets: state.application.questionSets,
        configOptions: getConfigOptions(state),
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-navigation-container');
    customElements.whenDefined('bp-sdk-external-question-set-navigation-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  onRemoveActiveAnswerRequest() {
    this.removeActiveAnswerId();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  handleActiveQuestionSetUpdate(evt) {
    if (this.useExternal) {
      return;
    }
    evt.detail && this.updateActiveQuestionSet(evt.detail);
    this.removeActiveAnswerId();
  }
  componentWillUpdate() {
    this.handleSubscriptions();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-set-navigation-container", { configOptions: this.configOptions, questionSets: this.questionSets });
  }
  onQuestionSetsChange(sets) {
    var _a;
    this.activeId = sets === null || sets === void 0 ? void 0 : sets.active;
    this.questionSetList = (_a = sets === null || sets === void 0 ? void 0 : sets.list) !== null && _a !== void 0 ? _a : [];
  }
  onConfigOptionsChange(options) {
    var _a;
    this.isNavigationEnabled = (_a = options === null || options === void 0 ? void 0 : options.enableQuestionSetNavigation) !== null && _a !== void 0 ? _a : true;
  }
  renderInternal() {
    if (!canGetStore()) {
      return null;
    }
    return (h("bp-sdk-question-set-navigation", { activeId: this.activeId, questionSets: this.questionSetList, isNavigationEnabled: this.isNavigationEnabled }));
  }
  static get is() { return "bp-sdk-question-set-navigation-container"; }
  static get properties() { return {
    "questionSets": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IQuestionSetState",
        "resolved": "IQuestionSetState",
        "references": {
          "IQuestionSetState": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question sets injected from redux"
      }
    },
    "configOptions": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IConfigOptions",
        "resolved": "IConfigOptions",
        "references": {
          "IConfigOptions": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Web component configuration options injected from redux"
      }
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "questionSetList": {},
    "activeId": {},
    "isNavigationEnabled": {}
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "questionSets",
      "methodName": "onQuestionSetsChange"
    }, {
      "propName": "configOptions",
      "methodName": "onConfigOptionsChange"
    }]; }
  static get listeners() { return [{
      "name": "removeActiveAnswer",
      "method": "onRemoveActiveAnswerRequest",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "activeIdUpdate",
      "method": "handleActiveQuestionSetUpdate",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
