import { Component, h, Prop, State, Watch } from '@stencil/core';
export class BpSdkQuoteRequestLogoContainer {
  constructor() {
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-quote-request-logo-container');
    customElements.whenDefined('bp-sdk-external-quote-request-logo-container').then(() => {
      this.useExternal = true;
    });
    this.onCarrierChange(this.carrier);
    this.onCustomLogoBaseUrlChange(this.customLogoBaseUrl);
    this.onShowCustomLogoChange(this.showCustomLogo);
  }
  onCarrierChange(carrier) {
    this.name = carrier === null || carrier === void 0 ? void 0 : carrier.name;
    this.updateLogoUrl(carrier, this.customLogoBaseUrl, this.showCustomLogo);
  }
  onCustomLogoBaseUrlChange(customLogoBaseUrl) {
    this.updateLogoUrl(this.carrier, customLogoBaseUrl, this.showCustomLogo);
  }
  onShowCustomLogoChange(showCustomLogo) {
    this.updateLogoUrl(this.carrier, this.customLogoBaseUrl, showCustomLogo);
  }
  updateLogoUrl(carrier, baseUrl, showCustomLogo) {
    var _a;
    if (showCustomLogo) {
      this.logoUrl = `${baseUrl}${(_a = carrier === null || carrier === void 0 ? void 0 : carrier.name) === null || _a === void 0 ? void 0 : _a.toLowerCase()}.png`;
    }
    else {
      this.logoUrl = carrier === null || carrier === void 0 ? void 0 : carrier.logo_url;
    }
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-quote-request-logo-container", { carrier: this.carrier, customLogoBaseUrl: this.customLogoBaseUrl, showLogo: this.showLogo, showCustomLogo: this.showCustomLogo }));
  }
  renderInternal() {
    return h("bp-sdk-quote-request-logo", { logoUrl: this.logoUrl, name: this.name, showLogo: this.showLogo });
  }
  static get is() { return "bp-sdk-quote-request-logo-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-quote-request-logo-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-quote-request-logo-container.css"]
  }; }
  static get properties() { return {
    "carrier": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "ICarrier",
        "resolved": "ICarrier",
        "references": {
          "ICarrier": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Carrier information"
      }
    },
    "customLogoBaseUrl": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Custom logo base url"
      },
      "attribute": "custom-logo-base-url",
      "reflect": false
    },
    "showLogo": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show logo"
      },
      "attribute": "show-logo",
      "reflect": false
    },
    "showCustomLogo": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show custom logo"
      },
      "attribute": "show-custom-logo",
      "reflect": false
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "name": {},
    "logoUrl": {}
  }; }
  static get watchers() { return [{
      "propName": "carrier",
      "methodName": "onCarrierChange"
    }, {
      "propName": "customLogoBaseUrl",
      "methodName": "onCustomLogoBaseUrlChange"
    }, {
      "propName": "showCustomLogo",
      "methodName": "onShowCustomLogoChange"
    }]; }
}
