import { r as registerInstance, h, g as getElement } from './index-b4e0290f.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { v } from './index.esm.min-5e144817.js';
import { cloneApplicationForm, getFormId, isFormLocked, isFormCloned, userHasPermission, doesUserOwnApplicationForm, isFormLoaded, getPartnerEngineConfig } from '@boldpenguin/sdk-redux';

const bpSdkTakeOverCss = "";

let BpSdkTakeOver = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-take-over');
    customElements.whenDefined('bp-sdk-external-take-over').then(() => {
      this.useExternal = true;
    });
  }
  shouldRender() {
    return this.isFormLoaded && this.canTakeOver && !this.isOwner && !this.isCloned && !this.isLocked;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-take-over", { canTakeOver: this.canTakeOver, isCloned: this.isCloned, isLocked: this.isLocked, isOwner: this.isOwner, isFormLoaded: this.isFormLoaded, shouldRender: this.shouldRender(), takeOverHandler: this.takeOverHandler }));
  }
  renderInternal() {
    return (this.shouldRender() && (h("div", { class: "bp-sdk-take-over__container" }, h("bp-sdk-take-over-button", { onClick: this.takeOverHandler }))));
  }
};
BpSdkTakeOver.style = bpSdkTakeOverCss;

const bpSdkTakeOverContainerCss = "";

let BpSdkTakeOverContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, {
          cloneApplicationForm,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        appFormId: getFormId(state),
        isLocked: isFormLocked(state),
        isCloned: isFormCloned(state),
        canTakeOver: userHasPermission(state, { permission: v.TakeOver }),
        isOwner: doesUserOwnApplicationForm(state),
        isFormLoaded: isFormLoaded(state),
        config: getPartnerEngineConfig(state),
      };
    };
    this.takeOverHandler = () => {
      this.cloneApplicationForm({
        appFormId: this.appFormId,
        config: this.config,
      });
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-take-over-container');
    customElements.whenDefined('bp-sdk-external-take-over-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-take-over-container", { appFormId: this.appFormId, canTakeOver: this.canTakeOver, config: this.config, isCloned: this.isCloned, isLocked: this.isLocked, isOwner: this.isOwner, isFormLoaded: this.isFormLoaded, takeOverHandler: this.takeOverHandler }));
  }
  renderInternal() {
    return (h("bp-sdk-take-over", { canTakeOver: this.canTakeOver, isCloned: this.isCloned, isLocked: this.isLocked, isOwner: this.isOwner, isFormLoaded: this.isFormLoaded, takeOverHandler: this.takeOverHandler }));
  }
  get el() { return getElement(this); }
};
BpSdkTakeOverContainer.style = bpSdkTakeOverContainerCss;

export { BpSdkTakeOver as bp_sdk_take_over, BpSdkTakeOverContainer as bp_sdk_take_over_container };
