/// <reference types="googlemaps" />
import { IAnswer, IAddressGroupComponent } from '@boldpenguin/sdk-types';
import { EventEmitter } from '../../stencil-public-runtime';
interface AddressMap {
  [key: string]: {
    short: string;
    long: string;
  };
}
export declare class BpSdkAddressGroup implements IAddressGroupComponent {
  /**
   * group of answers
   */
  answers: IAnswer[];
  /**
   * label
   */
  label: string;
  /**
   *  Labels that describe group
   */
  labelledBy: string;
  answerMap: {
    [key: string]: IAnswer;
  };
  useExternal: boolean;
  /**
   * Passes information needed to update answer
   */
  saveAnswer: EventEmitter<{
    answer: IAnswer;
    new_value: string | string[];
  }>;
  /**
   * Passes missing address_components
   */
  addressMissingComponents: EventEmitter<{
    missing_components: string[];
  }>;
  onAnswersChange(newAnswers: IAnswer[]): void;
  resetState(): void;
  connectedCallback(): void;
  componentWillLoad(): void;
  emitSaveAnswer(answer: IAnswer, newValue: string | string[]): void;
  onPlacesUpdate({ detail }: CustomEvent<google.maps.places.PlaceResult>): void;
  updateInputs: (address: AddressMap) => () => void;
  updateStreet(address: AddressMap): void;
  updateCity(address: AddressMap): void;
  updateState(address: AddressMap): void;
  updateZip(address: AddressMap): void;
  updateJson(place: google.maps.places.PlaceResult): void;
  /**
   * Emits addressMissingComponents event if any required
   * address components are missing
   *
   * @param addressComponents The array of address components from Google
   */
  handleMissingAddressComponents: (addressComponents: google.maps.GeocoderAddressComponent[]) => void;
  /**
   * Finds the address components that are missing in the Google data
   *
   * @param addressComponents The array of address components from Google
   * @returns Returns an array of missing address component types
   */
  getMissingAddressComponents: (addressComponents: google.maps.GeocoderAddressComponent[]) => string[];
  render(): any[];
  renderExternal(): any;
  renderInternal(): any;
}
export {};
